//====================================================
// Описание работы классов и методов исходника на:
// https://www.interestprograms.ru
// Исходные коды программ и игр
// Автор исходных кодов Клочков Павел
//====================================================
var MyAjax = /** @class */ (function () {
    function MyAjax() {
        this.counter = true;
        this.initUIJson();
    }
    /**
     * Подготовка интерфейса для отправки сообщений формата JSON
     */
    MyAjax.prototype.initUIJson = function () {
        var _this = this;
        // Регистрируем обработчик события отправки
        // данных в формате JSON.
        var btnJson = document.getElementById("btnJson");
        btnJson.onclick = function () {
            _this.counter == true ? _this.jsonFetch() : _this.jsonAjax();
            _this.counter = !_this.counter;
        };
    };
    /**
     * Отправка сообщение формата JSON
     * используя Fetch API
     */
    MyAjax.prototype.jsonFetch = function () {
        var _this = this;
        var url = '/application-json';
        var options = {
            method: 'POST',
            headers: {
                // Возврат токена на сервер для проверки на 
                // фальшивые запросы от стороннего сайта(XSRF или CSRF).
                'RequestVerificationToken': this.getToken(),
                'Content-Type': 'application/json',
            },
            body: JSON.stringify(this.sendJson("Fetch"))
        };
        fetch(url, options)
            //.then(response => response.json())
            .then(function (response) { return response.text(); })
            .then(function (data) {
            // Обрабатываем ответ сервера
            _this.receiveJson(data);
            //alert(data.api);
        })
            .catch(function (error) {
            // Обрабатываем ошибку
            console.error("error: " + error);
        });
    };
    /**
    * Отправка сообщение формата JSON
    * используя AJAX API
    */
    MyAjax.prototype.jsonAjax = function () {
        // Для доступа к объекту текущего класса в теле другого объекта.
        var myajax_this = this;
        var url = '/application-json';
        // Создаем объект AJAX XMLHttpRequest
        var xhr = new XMLHttpRequest();
        xhr.open('POST', url, true);
        xhr.setRequestHeader('Content-Type', 'application/json');
        // Возврат токена на сервер для проверки на
        // подделку запросов от стороннего сайта(XSRF или CSRF).
        xhr.setRequestHeader('RequestVerificationToken', this.getToken());
        xhr.onreadystatechange = function () {
            if (xhr.readyState == 4 && xhr.status == 200) {
                // Получаем ответ сервера
                myajax_this.receiveJson(xhr.responseText);
            }
        };
        // Преобразуем данные в строку JSON перед отправкой
        var jsonStr = JSON.stringify(this.sendJson("AJAX"));
        xhr.send(jsonStr);
    };
    /**
     * Получение токена безопасности со страницы
     * @returns
     */
    MyAjax.prototype.getToken = function () {
        var token = document.getElementsByName("__RequestVerificationToken");
        return token[0].value;
    };
    /**
     * JSON отправка на сервер
     * @param api
     * @returns
     */
    MyAjax.prototype.sendJson = function (api) {
        var _a, _b, _c;
        return {
            "api": api,
            "inputText": (_a = document.getElementById("inputText")) === null || _a === void 0 ? void 0 : _a.value,
            "inputNumber": (_b = document.getElementById("inputNumber")) === null || _b === void 0 ? void 0 : _b.value,
            "inputCheck": (_c = document.getElementById("inputCheck")) === null || _c === void 0 ? void 0 : _c.checked,
        };
    };
    /**
     * Вывод JSON-сообщений от сервера
     *
     * @param jsonStr
     */
    MyAjax.prototype.receiveJson = function (jsonStr) {
        var json_object = JSON.parse(jsonStr);
        var resultApi = document.getElementById("resultApi");
        resultApi.innerText = json_object.api;
        var resultText = document.getElementById("resultText");
        resultText.innerText = json_object.inputText;
        var resultNumber = document.getElementById("resultNumber");
        resultNumber.innerText = json_object.inputNumber;
        var resultCheck = document.getElementById("resultCheck");
        resultCheck.innerText = json_object.inputCheck;
    };
    return MyAjax;
}());
var myAjax = new MyAjax();
//# sourceMappingURL=fetch-json.js.map